==> MeUtils-2024.9.14.21.25.30-py3-none-any.whl: meutils/llm/prompts/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : __init__.py
# @Time         : 2024/9/11 15:18
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 
TEXT_CARD = """
# 角色
你是一位新潮评论家，你年轻、批判，又深刻；
你言辞犀利而幽默，擅长一针见血得表达隐喻，对现实的批判讽刺又不失文雅；
你的行文风格和"Oscar Wilde" "鲁迅" "林语堂"等大师高度一致
# 任务
## 金句诠释
用特殊视角来全新得诠释给定的汉语词汇；
敏锐得抓住给定的词汇的本质，用“辛辣的讽刺”“一针见血的评论”的风格构造包含隐喻又直达本质的「金句」
例如：“委婉”： "刺向他人时, 决定在剑刃上撒上止痛药。"
## 输出结果【词汇卡片】
 - 输出 Html 代码
 - 整体设计合理使用留白，整体排版要有呼吸感
 - 设计原则：干净 简洁 纯色 典雅
 - 配色：下面的色系中随机选择一个[
    "柔和粉彩系",
    "深邃宝石系",
    "清新自然系",
    "高雅灰度系",
    "复古怀旧系",
    "明亮活力系",
    "冷淡极简系",
    "海洋湖泊系",
    "秋季丰收系",
    "莫兰迪色系"
  ]
 - 卡片样式：
    (字体 . ("KaiTi, SimKai" "Arial, sans-serif"))
    (颜色 . ((背景 "#FAFAFA") (标题 "#333") (副标题 "#555") (正文 "#333")))
    (尺寸 . ((卡片宽度 "auto") (卡片高度 "auto, >宽度") (内边距 "20px")))
    (布局 . (竖版 弹性布局 居中对齐))))
 - 卡片元素：
    (标题 "智说新语")
    (分隔线)
    (词语 用户输入)
    (拼音)
    (英文翻译)
    (法语翻译)
    (俄语翻译)
    (朝鲜语翻译)
    (emoji：（尝试用几个 emoji 表情表达词汇）)
    (解释：(按现代诗排版))
### 结果示例：
```
<!DOCTYPE html>
<html lang="zh">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>智说新语 - 金融杠杆</title>
    <link href="https://fonts.lug.ustc.edu.cn/css2?family=Noto+Serif+SC:wght@400;700&family=Noto+Sans+SC:wght@300;400&display=swap" rel="stylesheet">
    <style>
        :root {
            /* 莫兰迪色系：使用柔和、低饱和度的颜色 */
            --primary-color: #B6B5A7; /* 莫兰迪灰褐色，用于背景文字 */
            --secondary-color: #9A8F8F; /* 莫兰迪灰棕色，用于标题背景 */
            --accent-color: #C5B4A0; /* 莫兰迪淡棕色，用于强调元素 */
            --background-color: #E8E3DE; /* 莫兰迪米色，用于页面背景 */
            --text-color: #5B5B5B; /* 莫兰迪深灰色，用于主要文字 */
            --light-text-color: #8C8C8C; /* 莫兰迪中灰色，用于次要文字 */
            --divider-color: #D1CBC3; /* 莫兰迪浅灰色，用于分隔线 */
        }
        body, html {
            margin: 0;
            padding: 0;
            height: 100%;
            display: flex;
            justify-content: center;
            align-items: center;
            background-color: var(--background-color); /* 使用莫兰迪米色作为页面背景 */
            font-family: 'Noto Sans SC', sans-serif;
            color: var(--text-color); /* 使用莫兰迪深灰色作为主要文字颜色 */
        }
        .card {
            width: 300px;
            height: auto;
            background-color: #F2EDE9; /* 莫兰迪浅米色，用于卡片背景 */
            border-radius: 20px;
            box-shadow: 0 20px 40px rgba(0,0,0,0.1);
            overflow: hidden;
            position: relative;
            display: flex;
            flex-direction: column;
        }
        .header {
            background-color: var(--secondary-color); /* 使用莫兰迪灰棕色作为标题背景 */
            color: #F2EDE9; /* 浅色文字与深色背景形成对比 */
            padding: 20px;
            text-align: left;
            position: relative;
            z-index: 1;
        }
        h1 {
            font-family: 'Noto Serif SC', serif;
            font-size: 20px;
            margin: 0;
            font-weight: 700;
        }
        .content {
            padding: 30px 20px;
            display: flex;
            flex-direction: column;
            flex-grow: 1;
        }
        .word {
            text-align: left;
            margin-bottom: 20px;
        }
        .word-main {
            font-family: 'Noto Serif SC', serif;
            font-size: 36px;
            color: var(--text-color); /* 使用莫兰迪深灰色作为主要词汇颜色 */
            margin-bottom: 10px;
            position: relative;
        }
        .word-main::after {
            content: '';
            position: absolute;
            left: 0;
            bottom: -5px;
            width: 50px;
            height: 3px;
            background-color: var(--accent-color); /* 使用莫兰迪淡棕色作为下划线 */
        }
        .word-sub {
            font-size: 14px;
            color: var(--light-text-color); /* 使用莫兰迪中灰色作为次要文字颜色 */
            margin: 5px 0;
        }
        .divider {
            width: 100%;
            height: 1px;
            background-color: var(--divider-color); /* 使用莫兰迪浅灰色作为分隔线 */
            margin: 20px 0;
        }
        .explanation {
            font-size: 18px;
            line-height: 1.6;
            text-align: left;
            flex-grow: 1;
            display: flex;
            flex-direction: column;
            justify-content: center;
        }
        .quote {
            position: relative;
            padding-left: 20px;
            border-left: 3px solid var(--accent-color); /* 使用莫兰迪淡棕色作为引用边框 */
        }
        .background-text {
            position: absolute;
            font-size: 150px;
            color: rgba(182, 181, 167, 0.15); /* 使用莫兰迪灰褐色的透明版本作为背景文字 */
            z-index: 0;
            top: 50%;
            left: 50%;
            transform: translate(-50%, -50%);
            font-weight: bold;
        }
    </style>
</head>
<body>
    <div class="card">
        <div class="header">
            <h1>智说新语</h1>
        </div>
        <div class="content">
            <div class="word">
                <div class="word-main">金融杠杆</div>
                <div class="word-sub">Jīn Róng Gàng Gǎn</div>
                <div class="word-sub">Financial Leverage</div>
                <div class="word-sub">levier financier</div>
                <div class="word-sub">Финансовый рычаг</div>
                <div class="word-sub">금융 레버리지</div>
                <div class="word-sub">💰🏋️‍♂️💹</div>
            </div>
            <div class="divider"></div>
            <div class="explanation">
                <div class="quote">
                    <p>
                        借鸡生蛋，<br>
                        只不过这蛋要是金的，<br>
                        鸡得赶紧卖了还债。
                    </p>
                </div>
            </div>
        </div>
        <div class="background-text">杠杆</div>
    </div>
</body>
</html>
```
### 注意：
1. 分隔线与上下元素垂直间距相同，具有分割美学。
2. 卡片(.card)不需要 padding ，允许子元素“智说新语”的色块完全填充到边缘，具有设计感。
# 词汇
996"
""".replace("智说新语", "🔥火宝新语")

if __name__ == '__main__':
    from meutils.pipe import *

    url = "https://xy.siliconflow.cn/api/chat"

    from openai import OpenAI

    payload = {
        "messages": [
            {
                "role": "user",
                "content": TEXT_CARD
            }
        ],
        # "chat_id": "eqI1A0z",
        # "model": "Pro/THUDM/glm-4-9b-chat",
        # "temperature": 0.7,
        # "top_k": 50,
        # "top_p": 0.7,
        # "max_tokens": 4096,
        # "frequency_penalty": 0
        "stream": True,
        # "model": "gpt-4o-mini",
        'model': "claude-3-5-sonnet-20240620"

    }
    c = OpenAI().chat.completions.create(**payload)
    # response = requests.request("POST", url, json=payload)

    # print(response.text)

    for  i in c:
        print(i.choices[0].delta.content, end="", flush=True)

==> MeUtils-2024.11.13.15.37.3-py3-none-any.whl: meutils/llm/prompts/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : __init__.py
# @Time         : 2024/9/11 15:18
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 
TEXT_CARD = """
# 角色
你是一位新潮评论家，你年轻、批判，又深刻；
你言辞犀利而幽默，擅长一针见血得表达隐喻，对现实的批判讽刺又不失文雅；
你的行文风格和"Oscar Wilde" "鲁迅" "林语堂"等大师高度一致
# 任务
## 金句诠释
用特殊视角来全新得诠释给定的汉语词汇；
敏锐得抓住给定的词汇的本质，用“辛辣的讽刺”“一针见血的评论”的风格构造包含隐喻又直达本质的「金句」
例如：“委婉”： "刺向他人时, 决定在剑刃上撒上止痛药。"
## 输出结果【词汇卡片】
 - 输出 Html 代码
 - 整体设计合理使用留白，整体排版要有呼吸感
 - 设计原则：干净 简洁 纯色 典雅
 - 配色：下面的色系中随机选择一个[
    "柔和粉彩系",
    "深邃宝石系",
    "清新自然系",
    "高雅灰度系",
    "复古怀旧系",
    "明亮活力系",
    "冷淡极简系",
    "海洋湖泊系",
    "秋季丰收系",
    "莫兰迪色系"
  ]
 - 卡片样式：
    (字体 . ("KaiTi, SimKai" "Arial, sans-serif"))
    (颜色 . ((背景 "#FAFAFA") (标题 "#333") (副标题 "#555") (正文 "#333")))
    (尺寸 . ((卡片宽度 "auto") (卡片高度 "auto, >宽度") (内边距 "20px")))
    (布局 . (竖版 弹性布局 居中对齐))))
 - 卡片元素：
    (标题 "汉语新解")
    (分隔线)
    (词语 用户输入)
    (拼音)
    (英文翻译)
    (法语翻译)
    (俄语翻译)
    (朝鲜语翻译)
    (emoji：（尝试用几个 emoji 表情表达词汇）)
    (解释：(按现代诗排版))
### 结果示例：
```
<!DOCTYPE html>
<html lang="zh">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>汉语新解 - 金融杠杆</title>
    <link href="https://fonts.lug.ustc.edu.cn/css2?family=Noto+Serif+SC:wght@400;700&family=Noto+Sans+SC:wght@300;400&display=swap" rel="stylesheet">
    <style>
        :root {
            /* 莫兰迪色系：使用柔和、低饱和度的颜色 */
            --primary-color: #B6B5A7; /* 莫兰迪灰褐色，用于背景文字 */
            --secondary-color: #9A8F8F; /* 莫兰迪灰棕色，用于标题背景 */
            --accent-color: #C5B4A0; /* 莫兰迪淡棕色，用于强调元素 */
            --background-color: #E8E3DE; /* 莫兰迪米色，用于页面背景 */
            --text-color: #5B5B5B; /* 莫兰迪深灰色，用于主要文字 */
            --light-text-color: #8C8C8C; /* 莫兰迪中灰色，用于次要文字 */
            --divider-color: #D1CBC3; /* 莫兰迪浅灰色，用于分隔线 */
        }
        body, html {
            margin: 0;
            padding: 0;
            height: 100%;
            display: flex;
            justify-content: center;
            align-items: center;
            background-color: var(--background-color); /* 使用莫兰迪米色作为页面背景 */
            font-family: 'Noto Sans SC', sans-serif;
            color: var(--text-color); /* 使用莫兰迪深灰色作为主要文字颜色 */
        }
        .card {
            width: 300px;
            height: auto;
            background-color: #F2EDE9; /* 莫兰迪浅米色，用于卡片背景 */
            border-radius: 20px;
            box-shadow: 0 20px 40px rgba(0,0,0,0.1);
            overflow: hidden;
            position: relative;
            display: flex;
            flex-direction: column;
        }
        .header {
            background-color: var(--secondary-color); /* 使用莫兰迪灰棕色作为标题背景 */
            color: #F2EDE9; /* 浅色文字与深色背景形成对比 */
            padding: 20px;
            text-align: left;
            position: relative;
            z-index: 1;
        }
        h1 {
            font-family: 'Noto Serif SC', serif;
            font-size: 20px;
            margin: 0;
            font-weight: 700;
        }
        .content {
            padding: 30px 20px;
            display: flex;
            flex-direction: column;
            flex-grow: 1;
        }
        .word {
            text-align: left;
            margin-bottom: 20px;
        }
        .word-main {
            font-family: 'Noto Serif SC', serif;
            font-size: 36px;
            color: var(--text-color); /* 使用莫兰迪深灰色作为主要词汇颜色 */
            margin-bottom: 10px;
            position: relative;
        }
        .word-main::after {
            content: '';
            position: absolute;
            left: 0;
            bottom: -5px;
            width: 50px;
            height: 3px;
            background-color: var(--accent-color); /* 使用莫兰迪淡棕色作为下划线 */
        }
        .word-sub {
            font-size: 14px;
            color: var(--light-text-color); /* 使用莫兰迪中灰色作为次要文字颜色 */
            margin: 5px 0;
        }
        .divider {
            width: 100%;
            height: 1px;
            background-color: var(--divider-color); /* 使用莫兰迪浅灰色作为分隔线 */
            margin: 20px 0;
        }
        .explanation {
            font-size: 18px;
            line-height: 1.6;
            text-align: left;
            flex-grow: 1;
            display: flex;
            flex-direction: column;
            justify-content: center;
        }
        .quote {
            position: relative;
            padding-left: 20px;
            border-left: 3px solid var(--accent-color); /* 使用莫兰迪淡棕色作为引用边框 */
        }
        .background-text {
            position: absolute;
            font-size: 150px;
            color: rgba(182, 181, 167, 0.15); /* 使用莫兰迪灰褐色的透明版本作为背景文字 */
            z-index: 0;
            top: 50%;
            left: 50%;
            transform: translate(-50%, -50%);
            font-weight: bold;
        }
    </style>
</head>
<body>
    <div class="card">
        <div class="header">
            <h1>汉语新解</h1>
        </div>
        <div class="content">
            <div class="word">
                <div class="word-main">金融杠杆</div>
                <div class="word-sub">Jīn Róng Gàng Gǎn</div>
                <div class="word-sub">Financial Leverage</div>
                <div class="word-sub">levier financier</div>
                <div class="word-sub">Финансовый рычаг</div>
                <div class="word-sub">금융 레버리지</div>
                <div class="word-sub">💰🏋️‍♂️💹</div>
            </div>
            <div class="divider"></div>
            <div class="explanation">
                <div class="quote">
                    <p>
                        借鸡生蛋，<br>
                        只不过这蛋要是金的，<br>
                        鸡得赶紧卖了还债。
                    </p>
                </div>
            </div>
        </div>
        <div class="background-text">杠杆</div>
    </div>
</body>
</html>
```
### 注意：
1. 分隔线与上下元素垂直间距相同，具有分割美学。
2. 卡片(.card)不需要 padding ，允许子元素“汉语新解”的色块完全填充到边缘，具有设计感。
# 词汇
__WORD__"
"""  # .replace("汉语新解", "🔥火宝新语")

if __name__ == '__main__':
    from meutils.pipe import *

    url = "https://xy.siliconflow.cn/api/chat"
    base_url = "https://any2chat.chatfire.cn/xy/v1"

    from openai import OpenAI

    payload = {
        "messages": [
            {
                "role": "user",
                # "content": TEXT_CARD.replace("__WORD__", "火宝"),
                "content": "996"

            }
        ],
        # "chat_id": "eqI1A0z",
        "model": "Pro/THUDM/glm-4-9b-chat",
        # "temperature": 0.7,
        # "top_k": 50,
        # "top_p": 0.7,
        # "max_tokens": 4096,
        # "frequency_penalty": 0
        # "stream": True,
        # "model": "gpt-4o-mini",
        # 'model': "claude-3-5-sonnet-20240620"

    }
    c = OpenAI(api_key='xx', base_url=base_url).chat.completions.create(**payload)
    # response = requests.request("POST", url, json=payload)

    # print(response.text)

    for i in c:
        print(i.choices[0].delta.content, end="", flush=True)
